* 11maps.do (GENERATING MAPS FOUND IN THE PAPER AND THE ONLINE APPENDIX, FEMALE LABOR FORCE PARTICIPATION)
* Ana Rute Cardoso w/ Louis-Philippe Morin
* December 2022
******************************************

* If needed
ssc install spmap, replace    // for maps
ssc install shp2dta, replace  // shapefiles to dta. For v14 or below
ssc install geo2xy, replace   // for fixing the coordinate system
ssc install palettes, replace
net install cleanplots, from("https://tdmize.github.io/data/cleanplots")
set scheme cleanplots

* Codes adapted from Asjad Naqvi's "Stata Graphs: Reprogramming maps" and "Maps in Stata II"
* "https://medium.com/the-stata-guide/stata-graphs-reprogramming-maps-204f9ec3f2e4
* https://medium.com/the-stata-guide/maps-in-stata-ii-fcb574270269

* District and Municipality Data Obtained from the European Environment Agency
* https://www.eea.europa.eu/data-and-maps/data/eea-reference-grids-2/gis-files/portugal-shapefile, accessed December 5, 2022
* NUTS3 Information obtained from IPUMS International
* https://international.ipums.org/international-action/variables/ENUTS3#codes_section , accessed October 6, 2016 .
* The correspondence was done using Instituto Nacional de Estatistica (INE)'s correspondence table.
* See pt_nuts2002_distrito_municipio_population.xlsx for details

* Converting .shp into .dta
clear
cd "/Users/lpm/Library/CloudStorage/Dropbox/gender_LM_participation/LATEST_replication/"
capture log close
log using "logs/11maps.log", replace nomsg
cd "/Users/lpm/Library/CloudStorage/Dropbox/gender_LM_participation/LATEST_replication/data/replic_stata_data/"
spshape2dta "concelhos.shp", replace saving(concelhos)
spshape2dta "distritos.shp", replace saving(distritos)
spshape2dta "ENUTS3.shp", replace saving(nuts3)

cd "/Users/lpm/Library/CloudStorage/Dropbox/gender_LM_participation/LATEST_replication/"
* Dropping the Azores and Madeira for Emig and Population Maps (Districts)
use "data/replic_stata_data/distritos_shp.dta", clear
drop if _ID==3 | _ID==13
save "data/replic_stata_data/distritos_shp2.dta", replace
* Applying Web Mercator projection for better map aspect 
geo2xy _Y _X, proj (web_mercator) replace
save "data/replic_stata_data/distritos_shp3.dta", replace

* Dropping the Azores and Madeira for Emig and Population Maps (NUTS)
use "data/replic_stata_data/nuts3.dta", clear
keep if CNTRY_CODE=="620"
drop if _ID==244 | _ID==245
save "data/replic_stata_data/nuts3_3.dta", replace

use "data/replic_stata_data/nuts3_shp.dta", clear
drop if _ID==244 | _ID==245
save "data/replic_stata_data/nuts3_shp2.dta", replace
geo2xy _Y _X, proj (web_mercator) replace
save "data/replic_stata_data/nuts3_shp3.dta", replace


* Merging _CX and _CY with _X and _Y, and applying Mercator projection
use "data/replic_stata_data/concelhos.dta", clear
merge 1:m _ID using "data/replic_stata_data/concelhos_shp.dta"
drop if ID_1==3 | ID_1==13
egen tag = tag(_ID) 
geo2xy _Y _X, proj (web_mercator) replace
geo2xy _CY _CX, proj (web_mercator) replace
gen layer = "concelhos"
order layer 
rename ID_0 CNTR_CODE
rename NAME_2 name
rename CCA_2 NUTS_ID
keep layer _ID _Y _X _CY _CX tag shape_order NUTS_ID CNTR_CODE name
sort _ID shape_order
compress
save "data/replic_stata_data/ptconcelhos_clean.dta", replace
clear

* Districts
use "data/replic_stata_data/distritos.dta", clear
merge 1:m _ID using "data/replic_stata_data/distritos_shp.dta"
drop if ID_1==3 | ID_1==13
egen tag = tag(_ID) 
geo2xy _Y _X, proj (web_mercator) replace
geo2xy _CY _CX, proj (web_mercator) replace
gen layer = "distritos"
order layer 
rename ID_0 CNTR_CODE
rename NAME_1 name
rename CCA_1 NUTS_ID
keep layer _ID _Y _X _CY _CX tag shape_order NUTS_ID CNTR_CODE name
sort _ID shape_order
compress
save "data/replic_stata_data/ptdistritos_clean.dta", replace
clear


* Data without Azores and Madeira
use "data/replic_stata_data/distritos.dta", clear
drop if ID_1==3 | ID_1==13
geo2xy _CY _CX, proj (web_mercator) replace
save "data/replic_stata_data/distritos3.dta", replace


use "data/replic_stata_data/nuts3.dta", clear
merge 1:m _ID using "data/replic_stata_data/nuts3_shp.dta"
keep if CNTRY_CODE=="620"
drop if _ID==244 | _ID==245
egen tag = tag(_ID) 
geo2xy _Y _X, proj (web_mercator) replace
geo2xy _CY _CX, proj (web_mercator) replace
gen layer = "nuts3"
order layer 
gen CNTR_CODE=182
gen NUTS_ID=ENUTS3
rename ENUTS3 name
replace name="Minho-Lima" if name=="22111"
replace name="Cávado" if name=="22112"
replace name="Ave" if name=="22113"
replace name="Grande Porto" if name=="22114"
replace name="Tâmega" if name=="22115"
replace name="Entre Douro e Vouga" if name=="22116"
replace name="Douro" if name=="22117"
replace name="Alto Trás-os-Montes" if name=="22118"
replace name="Algarve" if name=="22150"
replace name="Baixo Vouga" if name=="22161"
replace name="Baixo Mondego" if name=="22162"
replace name="Pinhal Litoral" if name=="22163"
replace name="Dão-Lafões" if name=="22165"
replace name="Oeste" if name=="22166"
replace name="Médio Tejo" if name=="22167"
replace name="Other Center" if name=="22169"
replace name="Grande Lisboa" if name=="22171"
replace name="Península de Setúbal" if name=="22172"
replace name="Lezíria do Tejo" if name=="22185"
replace name="Other Alentejo" if name=="22189"
keep layer _ID _Y _X _CY _CX tag shape_order NUTS_ID CNTR_CODE name
sort _ID shape_order
compress
save "data/replic_stata_data/ptnuts3_clean.dta", replace
* Saving Labels for Population Map
keep _ID _CY _CX NUTS_ID name
save "data/replic_stata_data/ptnuts3_labels.dta", replace
clear

* Merging Munipality, District, and NUT Data
use "data/replic_stata_data/ptconcelhos_clean.dta", clear
append using "data/replic_stata_data/ptdistritos_clean.dta"
append using "data/replic_stata_data/ptnuts3_clean.dta"
save "data/replic_stata_data/map_background_data.dta", replace

* Online Appendix Figure B.4

local area2  
   
sum _Y
local ymax = `r(max)'
local ymin = `r(min)'
sum _X
local xmax = `r(max)'
local xmin = `r(min)'
   
local aratio = (`ymax' - `ymin') / (`xmax' - `xmin')    
display `aratio'
local xsize = 10
local ysize = `xsize' * `aratio'
levelsof NUTS_ID if layer=="nuts3", local(lvls)
return list
local shapes = `r(r)'
local i = 1
foreach x of local lvls {

 colorpalette viridis, n(`shapes') nograph reverse

 
 local area2 `area2' (area _Y _X  if layer=="nuts3" & NUTS_ID=="`x'", nodropbase cmissing(n) fi(100) fc("`r(p`i')'%80") lc(gs4)  lw(0.06)  lp(solid)) || 
 
 local i = `i' + 1
}
twoway /// 
 `area2' ///
 (line _Y _X  if layer=="concelhos", nodropbase cmissing(n) lc(gs6)    lw(0.05) lp(solid)) ///
 (line _Y _X  if layer=="distritos", nodropbase cmissing(n) lc(gs2)   lw(0.25 ) lp(solid)) ///
  (scatter _CY _CX  if layer=="nuts3" & tag==1, mc(none) ms(point) mlab(name) mlabpos(0) mlabc(black) mlabsize(*0.75)), ///
   xlabel(, labsize(vsmall)) ///
   ylabel(, labsize(vsmall)) ///
   legend(order( 21 "Municipalities" 22 "Disctricts" 20 "NUTS 3") position(5) ring(0) size(vsmall) region(fcolor(none))) ///
   xtitle("") ytitle("")  ///
   aspect(`aratio')  xsize(`xsize') ysize(`ysize')
   *graph save "Graph" "graphs/Colored_NUTS_print.gph", replace
   graph export "graphs/Cardoso-Figure-B4.pdf", as(pdf) name("Graph") replace

clear

*********
* Preparing Data for Maps with NUTS3 Delimitations   
*********


* Change in R (1981)
use "data/replic_stata_data/change_R.dta", clear
rename region ENUTS3
replace ENUTS3=21000+ENUTS3
tostring ENUTS3, replace force
save "data/replic_stata_data/change_R_map.dta", replace

* Emigration Share (1950s)
use "data/replic_stata_data/weights_emig_region_50s_60s.dta", clear
rename region ENUTS3
replace ENUTS=21000+ENUTS3
tostring ENUTS3, replace force
forvalues i = 5(1)6 {
	replace wgt_emig`i'0s=100*wgt_emig`i'0s
}
save "data/replic_stata_data/emig_NUTS3.dta", replace

* NUTS Population 1950

use "data/replic_stata_data/pop50_nuts3.dta", clear
destring nuts3ipums, replace
gen ENUTS3=22000+nuts3ipums
tostring ENUTS3, replace
gen sh_pop=100*pop50_region/pop50_PT
gen pop1951000=round(pop50_region/1000,0.1)
save "data/replic_stata_data/pop_NUTS3_maps.dta", replace

* NUTS Characteristics 


use "data/replic_stata_data/educ_work_by_region_1950_1960.dta", clear
gen ENUTS3=21000+region
tostring ENUTS3, replace
foreach i in activrate1950_region shagric1950_region shliterate1950_region {
replace `i'=round(100*`i',0.1)	
}
save "data/replic_stata_data/charact_NUTS3_maps.dta", replace


*******
* Constructing Figure 5 Maps (Run until the end of the do-file to get proper map dimensions)
*******
* Must be run one-shot through the maps
* Defining Aspect Ratio
use "data/replic_stata_data/ptnuts3_clean.dta", clear
local area2  
sum _Y
local ymax = `r(max)'
local ymin = `r(min)'
sum _X
local xmax = `r(max)'
local xmin = `r(min)'
   
local aratio = (`ymax' - `ymin') / (`xmax' - `xmin')    
display `aratio'
local xsize = 10
local ysize = `xsize' * `aratio'
display `ysize'

clear
import excel "replic_data/pt_nuts_distrito_municipio_population.xlsx", sheet("to_stata") firstrow allstring
destring nuts3ipums pop_municip, replace
gen ENUTS3=22000+nuts3ipums
tostring ENUTS3, replace
collapse (sum) pop_municip, by(ENUTS3)
merge 1:1 ENUTS3 using "data/replic_stata_data/nuts3_3.dta"
gen pop1961000=round(pop_municip/1000,0.1)
drop _merge
merge 1:1 ENUTS3 using "data/replic_stata_data/change_R_map.dta"
gen Rchange2=round(-Rchange,0.001)
drop _merge
merge 1:1 ENUTS3 using "data/replic_stata_data/emig_NUTS3.dta"
drop _merge
merge 1:1 ENUTS3 using "data/replic_stata_data/pop_NUTS3_maps.dta"
gen rel_emig=round(wgt_emig50s/sh_pop,0.01)
gen emig_rate=round(100*Nemig50s/pop50_region,0.01)
drop _merge
merge 1:1 ENUTS3 using "data/replic_stata_data/charact_NUTS3_maps.dta"
drop _merge
geo2xy _CY _CX, proj (web_mercator) replace


* Online Appendix Table E.1
reg emig_rate pop1951000, r
reg emig_rate shagric1950_region, r
reg emig_rate shliterate1950_region, r
reg emig_rate activrate1950_region, r
reg Rchange emig_rate, r
sum emig_rate Rchange



* Figure 5 Top-Left Map
spmap emig_rate using "data/replic_stata_data/nuts3_shp3", title("1950s Emigration Rate") ///
id(_ID) cln(10)  fcolor(Heat) ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Emigration Rate (%)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off)) 
*graph save "Graph" "emig_rate_50s.gph", replace
graph export "graphs/Cardoso-Figure-5a-Color.pdf", as(pdf) name("Graph") replace 
   
* Figure 5 Top-Center Map
spmap pop1951000 using "data/replic_stata_data/nuts3_shp3",  title("1950 Population") ///
id(_ID) cln(10)  fcolor(Heat) ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Population (000s)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off))
*graph save "Graph" "NUTS_1951_Pop.gph", replace
graph export "graphs/Cardoso-Figure-5b-Color.pdf", as(pdf) name("Graph") replace 
  
* Figure 5 Top-Right Map
spmap shagric1950_region using "data/replic_stata_data/nuts3_shp3",  title("1950 Agriculture Share") ///
id(_ID) cln(10)  fcolor(Heat) ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Agriculture Share (%)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off)) 
*graph save "Graph" "Agri_sh50.gph", replace
graph export "graphs/Cardoso-Figure-5c-Color.pdf", as(pdf) name("Graph") replace 

* Figure 5 Bottom-Left Map
spmap shliterate1950_region using "data/replic_stata_data/nuts3_shp3",  title("1950 Literacy Rate") ///
id(_ID) cln(10)  fcolor(Heat) ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Literacy Rate (%)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off)) 
*graph save "Graph" "LR_50.gph", replace
graph export "graphs/Cardoso-Figure-5d-Color.pdf", as(pdf) name("Graph") replace 

* Figure 5 Bottom-Middle Map
spmap activrate1950_region using "data/replic_stata_data/nuts3_shp3",  title("1950 Activity Rate") ///
id(_ID) cln(10)  fcolor(Heat) ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Activity Rate (%)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off)) 
*graph save "Graph" "AR_50.gph", replace
graph export "graphs/Cardoso-Figure-5e-Color.pdf", as(pdf) name("Graph") replace 

* Figure 5 Bottom-Right Map
spmap Rchange2 using "data/replic_stata_data/nuts3_shp3",   title("Birth vs 1981 Observed Sex Ratio")  ///
id(_ID) cln(10)  fcolor(Heat) ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Sex-Ratio Drop (Birth minus Observed)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off)) 
*graph save "Graph" "NUTS_R_change.gph", replace
graph export "graphs/Cardoso-Figure-5f-Color.pdf", as(pdf) name("Graph") replace 

**************************************
* Figure 5 in Black and White (Print)*
**************************************

* Pick one colour pattern for black-white-friendly printing
colorpalette viridis, n(10) nograph reverse 
local colors `r(p)'

* Figure 5 Top-Left Map
spmap emig_rate using "data/replic_stata_data/nuts3_shp3", title("1950s Emigration Rate") ///
id(_ID) cln(10)  fcolor("`colors'") ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Emigration Rate (%)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off)) 
*graph save "Graph" "emig_rate_50s_BW.gph", replace
graph export "graphs/Cardoso-Figure-5a-Black-White.pdf", as(pdf) name("Graph") replace

* Figure 5 Top-Center Map
spmap pop1951000 using "data/replic_stata_data/nuts3_shp3",  title("1950 Population") ///
id(_ID) cln(10)  fcolor("`colors'") ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Population (000s)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off))
*graph save "Graph" "NUTS_1951_Pop_BW.gph", replace
graph export "graphs/Cardoso-Figure-5b-Black-White.pdf", as(pdf) name("Graph") replace

* Figure 5 Top-Right Map
spmap shagric1950_region using "data/replic_stata_data/nuts3_shp3",  title("1950 Agriculture Share") ///
id(_ID) cln(10)  fcolor("`colors'") ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Agriculture Share (%)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off)) 
*graph save "Graph" "Agri_sh50_BW.gph", replace
graph export "graphs/Cardoso-Figure-5c-Black-White.pdf", as(pdf) name("Graph") replace

* Figure 5 Bottom-Left Map
spmap shliterate1950_region using "data/replic_stata_data/nuts3_shp3",  title("1950 Literacy Rate") ///
id(_ID) cln(10)  fcolor("`colors'") ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Literacy Rate (%)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off)) 
*graph save "Graph" "LR_50_BW.gph", replace
graph export "graphs/Cardoso-Figure-5d-Black-White.pdf", as(pdf) name("Graph") replace

* Figure 5 Bottom-Middle Map
spmap activrate1950_region using "data/replic_stata_data/nuts3_shp3",  title("1950 Activity Rate") ///
id(_ID) cln(10)  fcolor("`colors'") ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Activity Rate (%)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off)) 
*graph save "Graph" "AR_50_BW.gph", replace
graph export "graphs/Cardoso-Figure-5e-Black-White.pdf", as(pdf) name("Graph") replace  

* Figure 5 Bottom-Right Map
spmap Rchange2 using "data/replic_stata_data/nuts3_shp3", title("Birth vs 1981 Observed Sex Ratio")  ///
id(_ID) cln(10)  fcolor("`colors'") ///
ocolor(black ..) osize(0.13 ..) ///
legend(title("Sex-Ratio Drop (Birth minus Observed)", size(*0.5)) pos(5) ring(0) size(vsmall) region(fcolor(none)))  legstyle(2) ///
label(data("data/replic_stata_data/ptnuts3_labels") xcoord(_CX) ycoord(_CY) label(name) length(30) color(black) size(*0.75))  legl("NUTS 3") ///
xtitle("") ytitle("")  ///
xsize(`xsize') ysize(`ysize') ///
polygon(data("data/replic_stata_data/ptconcelhos_clean") ocolor(gs7) osize(0.03)  legenda(off)) 
*graph save "Graph" "NUTS_R_change_BW.gph", replace
graph export "graphs/Cardoso-Figure-5f-Black-White.pdf", as(pdf) name("Graph") replace 

log close
