* 2read_births.do
* read worksheet with births 1900-1980
* Ana Rute Cardoso & Louis-Philippe Morin
* Jul 2023
******************************************
clear all
capture program drop _all
version 16
capture log close
log using ..\replic_logs\2read_births.log, replace nomsg

*** import births 1900-1980

import excel using ..\replic_data\births_1900_1980_original.xlsx, sheet(1900-1980_ydg) firstrow case(preserve) clear 

* keep only continental portugal

drop if distrito=="Ilhas" | distrito=="Madeira" | distrito=="Medeira" | distrito=="Funchal"               ///
     | distrito=="Azores" | distrito=="Angra do Heroismo" | distrito=="Horta" | distrito=="Ponta Delgada" ///
     | distrito=="Reino"  | distrito=="Portugal" | distrito=="unknown or different residence"

replace distrito="Castelo Branco" if distrito=="Castello Branco"
replace distrito="Viana do Castelo" if distrito=="Vianna do Castello"
replace distrito="Vila Real" if distrito=="Villa Real"

qui do codedistrict

keep     year district male female
save ..\_data\births_pt_yr_dist_gender_1900_1980.dta, replace

*** convert births by district into nuts

joinby district using ..\_data\allocation_district_to_nuts3ipums.dta

foreach g in male female {
	gen b`g' = `g' * alloc_dist_nuts if year>=1927  // setubal didn't exist before
	bys year nuts3ipums: egen bb`g' = total(b`g') if year>=1927 
	gen birth`g' = round(bb`g') if year>=1927
}
bys year nuts3ipums: keep if _n==1

* nuts3: original code as in ipums region of residence; harmonized variable "region"

gen region_orig = 22000+real(nuts3ipums)  // prefix 22, as in ipums residence nuts3 
gen region = 1000+real(nuts3ipums)        // short prefix 1 pt
qui do coderegion.do
label values region nuts3shortlb

ren year cohort
ren birthmale birth_inem
ren birthfemale birth_inef

keep cohort nuts3ipums nuts3ipums_txt region_orig region birth_inem birth_inef
save ..\_data\births_pt_yr_region_gender_1927_1980.dta, replace

log close
exit, clear
