* 3read_deaths_war.do
* read deaths in war in Africa
* Ana Rute Cardoso & Louis-Philippe Morin
* Jul 2023
******************************************
clear all
capture program drop _all
version 16
capture log close
log using ..\replic_logs\3read_deaths_war.log, replace nomsg

*** population data

* text p. 9 appendix 

use ..\_data\deaths_warafrica.dta, clear
keep if rank=="1Cb" | rank=="Fur" | rank=="Sld"
bys rank: tab death_age
bys rank death_age: keep if _N>3
keep if nuts3ipums!="" // Azores and Madeira not in analysis population
drop if death_year<1961 | death_year>1974  
save ..\_data\tmpdeathswar.dta, replace

*** distribution of death age within rank

gen obsage=1 if death_age!=.
collapse (sum) N_rank_age = obsage, by(rank death_age)
bys rank: egen N_rank = total(N)
gen shage_in_rank = N_rank_age / N_rank
keep if death_age!=.
keep rank death_age shage_in_rank
save ..\_data\tmpshage_in_rank.dta, replace

*** total deaths by region-rank-deathyear

use ..\_data\tmpdeathswar.dta, clear
gen a=1
collapse (sum) N_rg_rk_dyr = a, by(region rank death_year) 

*** infer death age for region from national distribution

joinby rank using ..\_data\tmpshage_in_rank.dta

gen N_rg_rk_dyr_age = N_rg_rk_dyr * shage_in_rank  
gen cohort = death_year - death_age

keep cohort region N_rg_rk_dyr_age
save ..\_data\deaths_war_rg_rk_dyr_age_coh.dta, replace

*** Figure 3a

cd ..\replic_graphs

collapse (sum) N_war_c = N_rg_rk_dyr_age, by(cohort)
graph bar N_war_c, over(cohort, label(angle(45))) ytitle("Number of Deaths in War") ///
      scheme(s1mono) saving(Cardoso-Figure-3a.gph, replace)
graph export "Cardoso-Figure-3a.eps", replace
graph export "Cardoso-Figure-3a.pdf", as(pdf) name("Graph") replace

*** Figure 3b

use cohort region birth_inem using ..\_data\births_pt_yr_region_gender_1927_1980.dta, clear
collapse (sum) birth_inem, by(cohort region) fast
save ..\_data\tmp_cells_birthine_cohortregion.dta, replace

use cohort region N_rg_rk_dyr_age using ..\_data\deaths_war_rg_rk_dyr_age_coh.dta, clear
collapse (sum) N_war_cr = N_rg_rk_dyr_age, by(cohort region) fast
replace N_war_cr = round(N_war_cr)

merge 1:1 cohort region using ..\_data\tmp_cells_birthine_cohortregion.dta
gen deaths_war_rateb = N_war_cr / birth_inem

label variable deaths_war_rateb "War Fatalities Rate (over Male Birth Cohort)"
label variable cohort   "Birth Cohort"

scatter deaths_war_rateb cohort if cohort>=1937 & cohort<=1954, ///
        xlabel(1937(5)1954)                                     ///
        scheme(s1mono) saving(Cardoso-Figure-3b.gph, replace)
graph export "Cardoso-Figure-3b.eps", replace
graph export "Cardoso-Figure-3b.pdf", as(pdf) name("Graph") replace

cd ..\replic_progs

log close
exit, clear
