* 4a_read_emig.do
* read worksheet with emigration 1950-1969
* Ana Rute Cardoso & Louis-Philippe Morin
* Jul 2023
******************************************
clear all
capture program drop _all
version 16
capture log close
log using ..\replic_logs\4a_read_emig.log, replace nomsg

*** number of legal emigrants by district: 1950s, 1960s, 1970s, 1980s

import excel using ..\replic_data\emig_1950-1988.xlsx, sheet(emigdist) firstrow case(preserve) clear 

* keep only continental portugal

drop if distrito=="Ilhas" | distrito=="Madeira" | distrito=="Medeira" | distrito=="Funchal"                ///
     | distrito=="Azores" | distrito=="Angra do Heroismo" | distrito=="Horta" | distrito=="Ponta Delgada"  ///
     | distrito=="Reino"  | distrito=="Portugal" | distrito=="unknown or different residence" |  distrito=="Unknown" 

* numeric district

qui do codedistrict

* decade

gen     decade="50s" if years=="1950-1959"
replace decade="60s" if years=="1960-1969"
replace decade="70s" if years=="1970-1979"
replace decade="80s" if years=="1980-1988"

*** allocate emigration from districts to nuts3

keep decade years district Nemig_legal wgt_emig_in_mainland
joinby district using ..\_data\allocation_district_to_nuts3ipums.dta

foreach v in Nemig_legal wgt_emig_in_mainland {
	gen tmp`v' = `v' * alloc_dist_nuts
	bys decade nuts3ipums: egen `v'_region = total(tmp`v')
}
replace Nemig_legal_region = round(Nemig_legal_region)

keep decade years nuts3ipums nuts3ipums_txt Nemig_legal_region  wgt_emig_in_mainland_region
bys decade nuts3ipums: keep if _n==1

* nuts3: original code as in ipums region of residence; harmonized variable "region"

gen region_orig = 22000+real(nuts3ipums)  // prefix 22, as in ipums residence nuts3
gen region = 1000+real(nuts3ipums)        // short prefix 1 pt
qui do coderegion.do
label values region nuts3shortlb

ren wgt_emig_in_mainland_region wgt_emig_in_mainland
label variable Nemig_legal_region "number of legal emigrants, by region"
label variable wgt_emig_in_mainland "share of region in legal emigrants of mainland"

keep decade years nuts3ipums nuts3ipums_txt region_orig region Nemig_legal_region wgt_emig_in_mainland
save ..\_data\emig_legal_by_region_50s_60s_70s_80s.dta, replace

log close
exit, clear
