* 4c_read_recruitment_war.do
* read worksheet with recruitment & draft avoidance
* Ana Rute Cardoso & Louis-Philippe Morin
* Jul 2023
******************************************
clear all
capture program drop _all
version 16
capture log close
log using ..\replic_logs\4c_read_recruitment_war.log, replace nomsg

*** recruitment and draft avoidance data

import excel using ..\replic_data\military_recruitment_1961_1974.xlsx, sheet(to_stata) firstrow case(preserve) clear 

* recode districts

qui do codedistrict

*** allocate registered & deliquents from district to region 

keep district birthsm1948 registered1968 delinq1968 wgt_delinq1968_in_mainland
joinby district using ..\_data\allocation_district_to_nuts3ipums.dta

foreach v in birthsm1948 registered1968 delinq1968 wgt_delinq1968_in_mainland {  // # or share in mainland is ok
   gen tmp`v'_ = `v' * alloc_dist_nuts
   bys nuts3ipums: egen `v'_reg = total(tmp`v')
}
foreach v in registered1968 delinq1968 {
   replace `v'_reg = round(`v'_reg)
}

gen shdelinq1968_reg = delinq1968_reg / registered1968_reg

keep nuts3ipums nuts3ipums_txt birthsm1948_reg registered1968_reg delinq1968_reg shdelinq1968_reg wgt_delinq1968_in_mainland_reg 
bys nuts3ipums: keep if _n==1

* nuts3: harmonized variable "region"

gen region = 1000+real(nuts3ipums)  // short prefix 1 pt
qui do coderegion.do
label values region nuts3shortlb

ren wgt_delinq1968_in_mainland_reg wgt_delinq1968_in_mainland

label variable registered1968_reg "number males in military census 1968, region"
label variable delinq1968_reg     "number of draft delinquents 1968 (no show, faltosos), region"
label variable shdelinq1968_reg   "share of draft delinquents over registered, 1968, region"
label variable wgt_delinq1968_in_mainl "share draft delinquents region over total continent 1968"

keep region birthsm1948 registered1968_reg delinq1968_reg shdelinq1968_reg wgt_delinq1968_in_mainland
save ..\_data\milit_recruit_delinq_by_region_1968.dta, replace

*** Figure 6: region weight in emigration 1950s vs weight in draft delinquency 1960s

use region wgt_delinq1968_in_mainland using ..\_data\milit_recruit_delinq_by_region_1968.dta, clear
merge 1:m region using ..\_data\emig_legal_by_region_50s_60s_70s_80s.dta, keepusing(decade wgt_emig_in_mainland)
keep if decade=="50s"

cd ..\replic_graphs
range a 0 .16 2
twoway (scatter wgt_delinq1968_in_mainland  wgt_emig_in_mainland, yscale(range(0 .16)))    ///
   (line a a, sort),                                                                       ///
   scheme(s1mono) legend(off)                                                              ///
   xtitle("Share of Region in Outflow Legal Migration 1950s") ytitle("Share of Region in Draft Delinquency 1968") ///
   saving(Cardoso-Figure-6.gph, replace)
graph export "Cardoso-Figure-6.eps", replace
graph export "Cardoso-Figure-6.pdf", as(pdf) name("Graph") replace

cd ..\replic_progs

log close
exit, clear
