* 5wbank_participation.do
* read worksheet participation rate from World Bank
* Ana Rute Cardoso & Louis-Philippe Morin
* Jul 2023
*************************************
clear all
capture program drop _all
version 16
capture log close
log using ..\replic_logs\5wbank_participation.log, replace nomsg

*** read World Bank data

import excel using ..\replic_data\world_bank_female_particip.xlsx, sheet(tostata) firstrow case(lower) clear 

reshape long yr, i(countrycode) j(year)
ren yr flfp

* circa year xxx0

foreach d in 1960 1970 1980 1990 2000 {
	gen circa`d'=`d' if year==`d' & flfp!=.
	sort countrycode year 
	by countrycode: replace circa`d'=`d' if circa`d'[_n-1]==. & year==`d'+1  & flfp!=.
}
replace circa1960=1960 if circa1960==. & countrycode=="FR" & year==1962
replace circa1960=1970 if circa1960==. & countrycode=="FR" & year==1975
replace circa1960=1960 if circa1960==. & countrycode=="SE" & year==1965
replace circa1960=1970 if circa1960==. & countrycode=="SE" & year==1975
replace circa1960=1980 if circa1980==. & countrycode=="SE" & year==1982
replace circa1960=1980 if circa1980==. & countrycode=="DE" & year==1983

gen circa=.
foreach d in 1960 1970 1980 1990 2000 {
	replace circa=circa`d' if circa==. & circa`d'!=.
}

label variable flfp "Female Activity Rate (%)"
label variable circa "Beginning of Decade"

drop if circa==.
keep country countrycode year circa flfp
save ..\_data\wbank_particip.dta, replace

*** Figure 1: histograms by decade

cd ..\replic_graphs

foreach d in 1960 1970 1980 1990 {
   use ..\_data\wbank_particip.dta if circa==`d', clear

   gen flfp1=flfp if countrycode=="PT"
   gen flfp2=flfp if countrycode=="ES"
   gen flfp3=flfp if countrycode!="PT" & countrycode!="ES"

   graph bar (asis) flfp1 flfp2 flfp3, nofill over(countrycode, sort(flfp))    ///
         bar(1, fintensity(100)) bar(2, fintensity(85)) bar(3, fintensity(10)) ///
         ytitle("female activity rate (%)")                                    /// 
         ylabel(0(10)80) t(`d')  legend(off)  scheme(s1mono)                   /// 
         saving(Cardoso-Figure-1_`d'.gph, replace)
   graph export "Cardoso-Figure-1_`d'.eps", replace
   graph export "Cardoso-Figure-1_`d'.pdf", as(pdf) name("Graph") replace
}

*** Figure 2: country trends, levels starting 1960

use ..\_data\wbank_particip.dta, clear

graph twoway  scatter flfp circa if countrycode=="SE", c(l) lp(_)  s(X) ///
           || scatter flfp circa if countrycode=="DK", c(l) lp(-)  s(O) ///
           || scatter flfp circa if countrycode=="NO", c(l) lp(l)  s(S) ///
           || scatter flfp circa if countrycode=="FI", c(l) lp(-.) s(t) ///
   ylabel(10(10)80)                                                     ///
   legend(lab(1 "SE") lab(2 "DK") lab(3 "NO") lab(4 "FI") cols(4))      ///
      scheme(s1mono) saving(Cardoso-Figure-2b.gph, replace)
   graph export "Cardoso-Figure-2b.eps", replace
   graph export "Cardoso-Figure-2b.pdf", as(pdf) name("Graph") replace

graph twoway  scatter flfp circa if countrycode=="IT", c(l) lp(_)  s(X)  ///
           || scatter flfp circa if countrycode=="ES", c(l) lp(-)  s(O)  ///
           || scatter flfp circa if countrycode=="PT", c(l) lp(l)  s(S)  ///
           || scatter flfp circa if countrycode=="GR", c(l) lp(-.) s(t)  ///
   ylabel(10(10)80)                                                      ///
   legend(lab(1 "IT") lab(2 "ES") lab(3 "PT") lab(4 "GR") cols(4))       ///
      scheme(s1mono) saving(Cardoso-Figure-2a.gph, replace)
   graph export "Cardoso-Figure-2a.eps", replace
   graph export "Cardoso-Figure-2a.pdf", as(pdf) name("Graph") replace

cd ..\replic_progs

log close
exit, clear