* 7analysis_flfp.do
* regressions female labor force participation
* Ana Rute Cardoso & Louis-Philippe Morin
* Jul 2023
******************************************
clear all
capture program drop _all
version 16
set seed 339487731

capture log close
log using ..\replic_logs\7analysis_flfp.log, replace nomsg

*** cohort windows 

program define sum_cohortwindow
sort year region cohort
   by year region: gen `1'_ba1  = `1'+`1'[_n-1]+`1'[_n+1]
   by year region: gen `1'_ba2  = `1'+`1'[_n-1]+`1'[_n-2]+`1'[_n+1]+`1'[_n+2]
   by year region: gen `1'_ba3  = `1'+`1'[_n-1]+`1'[_n-2]+`1'[_n-3]+`1'[_n+1]+`1'[_n+2]+`1'[_n+3]
end
// 1: variable to sum across neighboring cohorts 

*** prep data

use ..\_data\cells_year_cohortregion.dta, clear

* logs

foreach v in R popmf empmf qpempmf shdelinq shregist { 
   gen l`v' = log(`v')
}

* neighboring cohorts: sums 

foreach v in pop birth_ine emp qpemp { 
foreach g in m f mf { 
   sum_cohortwindow `v'`g'
}
}

foreach g in m f mf { 
   sum_cohortwindow em`g'_leavo
}

* neighboring cohorts: ratios and logs of interest

foreach w in _ba1 _ba2 _ba3  { 
   gen R`w' = popm`w' / popf`w'
   gen lR`w' = log(R`w')

   gen lpopmf`w' = log(popmf`w')
   gen lempmf`w' = log(empmf`w')
   gen lqpempmf`w' = log(qpempmf`w')

   foreach g in m f mf {
      gen em`g'_rate_leavo`w' = em`g'_leavo`w' / birth_ine`g'`w'
      label variable em`g'_rate_leavo`w' "leave-own-out `g' emig rate (over birth cohort), `w'"
   }
   gen  em_gender_leavo`w' = emm_rate_leavo`w' - emf_rate_leavo`w'
   label variable em_gender_leavo`w' "leave-own-out (emig/births)m - (emig/births)f, `w'"
}

* sex ratio centered at females' own cohort c and males' c-2 (for marriage regressions)
  // market size & population window accordingly

foreach v in popm  emm_leavo birth_inem  { 
   sort year region cohort
   by year region: gen `v'_befor2 = `v'[_n-2]
   by year region: gen `v'_bef1to3 = `v'[_n-1]+`v'[_n-2]+`v'[_n-3]
   by year region: gen `v'_bef0to4 = `v' + `v'[_n-1]+`v'[_n-2]+`v'[_n-3]+`v'[_n-4]
   by year region: gen `v'_b5a1 = `v' + `v'[_n-1]+`v'[_n-2]+`v'[_n-3]+`v'[_n-4]+`v'[_n-5] + `v'[_n+1]
}

gen lR_Mbef2_F0 = log(popm_befor2 / popf)
gen lR_Mb1to3_Fba1 = log(popm_bef1to3 / popf_ba1)
gen lR_Mb0to4_Fba2 = log(popm_bef0to4 / popf_ba2)
gen lR_Mb5a1_Fba3 = log(popm_b5a1 / popf_ba3)

gen lpopmf_Mbef2_F0 = log(popm_befor2 + popf)
gen lpopmf_Mb1to3_Fba1 = log(popm_bef1to3 + popf_ba1)
gen lpopmf_Mb0to4_Fba2 = log(popm_bef0to4 + popf_ba2)
gen lpopmf_Mb5a1_Fba3 = log(popm_b5a1 + popf_ba3)

gen emmf_rate_leavo_Mbef2_F0    = (emm_leavo_befor2  + emf_leavo) / (birth_inem_befor2 + birth_inef)
gen emmf_rate_leavo_Mb1to3_Fba1 = (emm_leavo_bef1to3 + emf_leavo_ba1) / (birth_inem_bef1to3 + birth_inef_ba1)
gen emmf_rate_leavo_Mb0to4_Fba2 = (emm_leavo_bef0to4 + emf_leavo_ba2) / (birth_inem_bef0to4 + birth_inef_ba2)
gen emmf_rate_leavo_Mb5a1_Fba3  = (emm_leavo_b5a1 + emf_leavo_ba3) / (birth_inem_b5a1 + birth_inef_ba3)

gen em_gender_leavo_Mbef2_F0    = (emm_leavo_befor2  / birth_inem_befor2)  - (emf_leavo / birth_inef)
gen em_gender_leavo_Mb1to3_Fba1 = (emm_leavo_bef1to3 / birth_inem_bef1to3) - (emf_leavo_ba1 / birth_inef_ba1)
gen em_gender_leavo_Mb0to4_Fba2 = (emm_leavo_bef0to4 / birth_inem_bef0to4) - (emf_leavo_ba2 / birth_inef_ba2)
gen em_gender_leavo_Mb5a1_Fba3  = (emm_leavo_b5a1 / birth_inem_b5a1)       - (emf_leavo_ba3 / birth_inef_ba3)

* keep only cohorts of interest

keep if cohort>=1937 & cohort<=1954 & age>=23 & age<=59

* dummies

xi, prefix(dr) i.region
xi, prefix(dc) i.cohort
xi, prefix(d) i.region*cohort
xi, prefix(cXar) i.cohort*activrate1960 
xi, prefix(cXgr) i.cohort*shagric1960
xi, prefix(cXur) i.cohort*urate1960
drop cXarcohort_* cXgrcohort_* cXurcohort_* // main effects computed (again) for interactions

ren shf_ingoodoccisco_pop_gap shf_goodoc_pop_gap

save ..\_data\regs_cohortsiv_emig.dta, replace

keep if cohort==1948
save ..\_data\regs_cohortsiv_delinq.dta, replace

*** age gap between spouses

use ..\_data\census_key_vars.dta if cohort>=1937 & cohort<=1954 & age>=23 & age<=59, clear
gen age_gap     = age - age_sp if sex==1 & sex_sp!=. & age!=. & age_sp!=.
replace age_gap = age_sp - age if sex==2 & sex_sp!=. & age!=. & age_sp!=.

sum age_gap, detail

*** Table 2: descriptive statistics for regressions PT

use ..\_data\regs_cohortsiv_emig.dta, clear

sum age Rbirth R evermarriedYNratef nchildratef ///
    activratef activratem                       ///
    lrwhf lrwhm gap_lrwh shf_ingoodoccisco      ///
    educyrsf Cempeducyrsf qpeducyrsf            ///
    educyrsm Cempeducyrsm qpeducyrsm            ///
    emmf_rate_leavo em_gender_leavo             /// 
    [aweight=popf]

tab cohort, sum(Rbirth)
tab cohort, sum(R)

*** regressions

* macros 

global windowown      ""
global windowemig     "_ba1 _ba2 _ba3"
global windowmarriage "_Mbef2_F0  _Mb1to3_Fba1  _Mb0to4_Fba2  _Mb5a1_Fba3"

global Xdumemig   "drregion* dccohort*"           
global Xregemig   "cXar* cXgr* cXu*"    
global ctrends    "drregion* dccohort* dregXcoh*"

global Xdumdelinq ""
global Xregdelinq "activrate1960 shagric1960 urate1960" 


* regressions

program define regs
   use ..\_data\regs_cohortsiv_`1'.dta, clear 
   display ""
   display ""
   display "-------------- outcome: `2' --------------"

   foreach w in  ""  `14' {
      if "`17'"!="twoway" {
         regress  `2'  lR`w'  `15'`w'  `5'  `7'  `16'  `11' [aweight=`8'], `10'
      }
      if "`17'"=="twoway" {
         *ols (no instruments specified):
         ivreg2  `2'  lR`w'  `15'`w'  `5'  `7'  `16'  `11' [aweight=`8'], `10'
      }
      `12'

      ivreg2  `2'  (lR`w'  `15'`w'  `5'  =  `3'`w'  `4'`w'  `6')  `7'  `16'  `11' [aweight=`8'],  `10'  `9'  `13'
      `12'

      if "`17'"=="y" {
         display "-------> reduced form"
         regress  `2'  `3'`w'  `4'`w'  `6'  `7'  `16'  `11' [aweight=`8'],  `10'
      }
   }
end

program define regsl
   use  cohort region lR* qpempmf lqpempmf lqpempmf_ba*                       /// 
        lrwhf lrwhm qpeducyrsm qpeducyrsf educyrsm educyrsf                   /// 
        emmf_rate_leavo emmf_rate_leavo_b* em_gender_leavo em_gender_leavo_b* ///
        drregion* dccohort* dregXcoh* cXar* cXgr* cXu*                        ///  
        using ..\_data\regs_cohortsiv_`1'.dta, clear 

   egen regcohort = group(region cohort)

   foreach v in lrwh educyrs qpeducyrs {
      ren `v'm `v'0
      ren `v'f `v'1
   }
   reshape long lrwh educyrs qpeducyrs, i(regcohort) j(female)

   foreach v in lR "lR_ba1" "lR_ba2" "lR_ba3" "em_gender_leavo" "em_gender_leavo_ba1" "em_gender_leavo_ba2" "em_gender_leavo_ba3"  educyrs qpeducyrs { // interaction terms Xfemale
      gen f`v' = female*`v'
   }
   display ""
   display ""
   display "-------------- outcome: `2' --------------"

   foreach w in  ""  `14' {
      if "`17'"!="twoway" {
         regress  `2'  lR`w'  flR`w'  `15'`w'  `5'  `7' female `16'  `11' [aweight=`8'], `10'
      }
      if "`17'"=="twoway" {
         *ols (no instruments specified):
         ivreg2  `2'  lR`w'  flR`w'  `15'`w'  `5'  `7' female `16'  `11' [aweight=`8'], `10'
      }
      `12'
      * iv:
      ivreg2  `2'  (lR`w'  flR`w'  `15'`w'  `5'  =  `3'`w'  f`3'`w'  `4'`w'  `6') `7' female `16'  `11' [aweight=`8'], `10' `9' `13'
      `12'
      lincom lR`w' + flR`w'

      if  "`17'"=="y" {
         display "-------> reduced form"
         regress  `2'  `3'`w'  f`3'`w'  `4'`w'  `6'  `7' female `16'  `11' [aweight=`8'], `10'
      }
   }
end

*    1file 2y                  3iv               4iv               5endog                 6iv                7exog         8weigt   9report  10clustering             11Xreg     12boot 13partial            14window          15market 16Xdummies   17reducf/twoway
* ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
************************* core: IV emig leave-out own region, no region controls *************************
regs  emig evermarriedYNratef  "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowemig"     lpopmf   "$Xdumemig"  y
regs  emig activratef          "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowemig"     lpopmf   "$Xdumemig"  y 
regs  emig shf_ingoodoccisco   "em_gender_leavo" "emmf_rate_leavo" "gap_Cempeducyrs"      "gap_educyrs"      ""            empmf    "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowemig"     lempmf   "$Xdumemig"  y
*regs  emig shf_in6occisco      "em_gender_leavo" "emmf_rate_leavo" "gap_Cempeducyrs"      "gap_educyrs"      ""            empmf    "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowemig"     lempmf   "$Xdumemig" y
regsl emig lrwh                "em_gender_leavo" "emmf_rate_leavo" "qpeducyrs fqpeducyrs" "educyrs feducyrs" ""            qpempmf  "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowemig"     lqpempmf "$Xdumemig"  y

************************* marriage, cohort window centered at females' own cohort c and males' c-2 (median age diff spouses) *************************
regs  emig evermarriedYNratef  "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowmarriage" lpopmf   "$Xdumemig"  n 

************************* additional outcomes *************************
regs  emig separYNf_ratemar    "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowemig"     lpopmf   "$Xdumemig"  n
regs  emig gap_evermarried_rat "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "gap_educyrs" popmf    "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowemig"     lpopmf   "$Xdumemig"  n
regs  emig gap_activrate       "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "gap_educyrs" popmf    "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowemig"     lpopmf   "$Xdumemig"  n
regs  emig uratef              "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowemig"     lpopmf   "$Xdumemig"  n
regs  emig empratef            "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowemig"     lpopmf   "$Xdumemig"  n
regs  emig shf_goodoc_pop_gap  "em_gender_leavo" "emmf_rate_leavo" "gap_Cempeducyrs"      "gap_educyrs"      ""            popmf    "first"  "cluster(region)"        ""           ""   "partial($Xdumemig)" "$windowemig"     lempmf   "$Xdumemig"  n

************************* two-way clusters *************************
regs  emig evermarriedYNratef  "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region cohort)" ""           ""   "partial($Xdumemig)" "$windowemig"     lpopmf   "$Xdumemig"  twoway
regs  emig activratef          "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region cohort)" ""           ""   "partial($Xdumemig)" "$windowemig"     lpopmf   "$Xdumemig"  twoway
regs  emig shf_ingoodoccisco   "em_gender_leavo" "emmf_rate_leavo" "gap_Cempeducyrs"      "gap_educyrs"      ""            empmf    "first"  "cluster(region cohort)" ""           ""   "partial($Xdumemig)" "$windowemig"     lempmf   "$Xdumemig"  twoway
regsl emig lrwh                "em_gender_leavo" "emmf_rate_leavo" "qpeducyrs fqpeducyrs" "educyrs feducyrs" ""            qpempmf  "first"  "cluster(region cohort)" ""           ""   "partial($Xdumemig)" "${windowemig}"   lqpempmf "$Xdumemig"  twoway

************************* cohort trends within region *************************
regs  emig evermarriedYNratef  "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"        ""           ""   "partial($ctrends)"  "$windowown"      lpopmf   "$ctrends"   n
regs  emig activratef          "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"        ""           ""   "partial($ctrends)"  "$windowown"      lpopmf   "$ctrends"   n
regs  emig shf_ingoodoccisco   "em_gender_leavo" "emmf_rate_leavo" "gap_Cempeducyrs"      "gap_educyrs"      ""            empmf    "first"  "cluster(region)"        ""           ""   "partial($ctrends)"  "$windowown"      lempmf   "$ctrends"   n
regsl emig lrwh                "em_gender_leavo" "emmf_rate_leavo" "qpeducyrs fqpeducyrs" "educyrs feducyrs" ""            qpempmf  "first"  "cluster(region)"        ""           ""   "partial($ctrends)"  "$windowown"      lqpempmf "$ctrends"   n

************************* with region controls *************************
regs  emig evermarriedYNratef  "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"        "$Xregemig"  ""   "partial($Xregemig $Xdumemig)"     "$windowown" lpopmf       "$Xdumemig"   n
regs  emig activratef          "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"        "$Xregemig"  ""   "partial($Xregemig $Xdumemig)"     "$windowown" lpopmf       "$Xdumemig"   n
regs  emig shf_ingoodoccisco   "em_gender_leavo" "emmf_rate_leavo" "gap_Cempeducyrs"      "gap_educyrs"      ""            empmf    "first"  "cluster(region)"        "$Xregemig"  ""   "partial($Xregemig $Xdumemig)"     "$windowown" lempmf       "$Xdumemig"   n
regsl emig lrwh                "em_gender_leavo" "emmf_rate_leavo" "qpeducyrs fqpeducyrs" "educyrs feducyrs" ""            qpempmf  "first"  "cluster(region)"        "$Xregemig"  ""   "partial($Xregemig $Xdumemig)"     "$windowown" lqpempmf     "$Xdumemig"   n


************************* bootstrap *************************
// note that boottest not compatible with partial

*    1file 2y                  3iv               4iv               5endog                 6iv                7exog         8weigt   9report  10clustering             11Xreg     12boot                                                   13partial 14window      15market 16Xdummies 17reducf/twoway
* ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
regs  emig evermarriedYNratef  "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"         ""        "boottest {lR} {lpopmf}, nograph level(90) small"         ""       "$windowemig" lpopmf   "$Xdumemig"  n
regs  emig activratef          "em_gender_leavo" "emmf_rate_leavo" ""                     ""                 "educyrsf"    popf     "first"  "cluster(region)"         ""        "boottest {lR} {lpopmf}, nograph level(90) small"         ""       "$windowemig" lpopmf   "$Xdumemig"  n
regs  emig shf_ingoodoccisco   "em_gender_leavo" "emmf_rate_leavo" "gap_Cempeducyrs"      "gap_educyrs"      ""            empmf    "first"  "cluster(region)"         ""        "boottest {lR} {lempmf}, nograph level(90) small"         ""       "$windowemig" lempmf   "$Xdumemig"  n
regsl emig lrwh                "em_gender_leavo" "emmf_rate_leavo" "qpeducyrs fqpeducyrs" "educyrs feducyrs" ""            qpempmf  "first"  "cluster(region)"         ""        "boottest {lR} {flR} {lqpempmf}, nograph level(90) small" ""       "$windowemig" lqpempmf "$Xdumemig"  n


************************* IV draft delinquency *************************
*     1file 2y                  3iv         4iv          5endog 6iv  7exog       8weigt 9report   10clustering      11Xreg         12boot 13partial                          14window      15market 16Xdummies    17reducf/twoway
* ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
regs delinq evermarriedYNratef "lshdelinq"  "lshregist"  ""     ""   "educyrsf"  popf    "first"  "cluster(region)" "$Xregdelinq"  ""    "partial($Xdumdelinq $Xregdelinq)"  "$windowown"  lpopmf   "$Xdumdelinq" n
regs delinq activratef         "lshdelinq"  "lshregist"  ""     ""   "educyrsf"  popf    "first"  "cluster(region)" "$Xregdelinq"  ""    "partial($Xdumdelinq $Xregdelinq)"  "$windowown"  lpopmf   "$Xdumdelinq" n

log close
exit, clear