* 9retornados.do
* regressions sex ratio retornados on IVs
* Ana Rute Cardoso & Louis-Philippe Morin
* Jul 2023
*******************************************
clear all
capture program drop _all
version 16
capture log close
log using ..\replic_logs\9retornados.log, replace nomsg

*** retornados in Census 1981

use C:\Ana_orig_censusIPUMS\IPUMS_portugal_census_1981_1991_2001_2011_DATA_ORIG.dta if year==1981, clear

*** retornado: born in Africa
*** in retornado household: member of household w/ at least 1 retornado

gen retorn=1 if bplcountry==10000 /// // Africa
              | bplcountry==11100 /// // Mozambique
              | bplcountry==12010 /// // Angola
              | bplcountry==12090 /// // Sao Tome and Principe
              | bplcountry==15030 /// // Cape Verde
              | bplcountry==15080 /// // Guinea-Bissau
              | bplcountry==15081     // Guinea-Bissau and Cape Verde
recode retorn .=0

bys serial: egen retornhh_tot = total(retorn)
gen retornhh = (retornhh_tot>=1)

gen retornhh_f=1 if retornhh==1 & sex==2
gen retornhh_m=1 if retornhh==1 & sex==1
recode retornhh_f .=0
recode retornhh_m .=0

*** birth cohort /* inferred, not reported in census portugal; census took place 16mar81 */

gen cohort = year-age-1

* nuts3: short coding of residence (prefix 1 portugal), drop islands

gen region = enuts3 
recode region 22111=1111 22112=1112 22113=1113 22114=1114 22115=1115 22116=1116 22117=1117 ///
   22118=1118 22150=1150 22161=1161 22162=1162 22163=1163 22169=1169 22165=1165 22166=1166 ///
   22167=1167 22171=1171 22172=1172 22185=1185 22189=1189 22200=1200 22300=1300 2299997=888888

qui do coderegion.do
label values region nuts3shortlb
drop if region >=1200

*** collapse by region & cohort

keep year perwt cohort region retornhh*
collapse (sum) retornhh_f retornhh_m [fweight=perwt], by(year cohort region) fast

*** sex ratio of retornados

gen Rretornhh = retornhh_m / retornhh_f
label variable Rretornhh "sex ratio M/F for retornados"

* cohort windows

program define sum_cohortwindow
   sort year region cohort
   by year region: gen `1'_ba1  = `1'+`1'[_n-1]+`1'[_n+1]
   by year region: gen `1'_ba2  = `1'+`1'[_n-1]+`1'[_n-2]+`1'[_n+1]+`1'[_n+2]
   by year region: gen `1'_ba3  = `1'+`1'[_n-1]+`1'[_n-2]+`1'[_n-3]+`1'[_n+1]+`1'[_n+2]+`1'[_n+3]
end

sum_cohortwindow retornhh_m 
sum_cohortwindow retornhh_f

foreach w in _ba1 _ba2 _ba3 { 
      gen Rretornhh`w' = retornhh_m`w' / retornhh_f`w'
}

*** merge to regression dataset in FLFP project

merge 1:1 year cohort region using ..\_data\regs_cohortsiv_emig.dta, keep(3)

*** regressions sex ratio retornados on IVs
*** Table F.4

foreach w in  "" _ba1 _ba2 _ba3 {
   regress Rretornhh`w'  em_gender_leavo`w' emmf_rate_leavo`w' educyrsf drregion* dccohort* [aweight=popf], cluster(region)
}

log close
exit, clear